@@ -12,7 +12,7 @@
 #include "relatedfeedbackwidget.h"
 
 RelatedFeedbackWidget::RelatedFeedbackWidget(QWidget *parent, const char *name)
- : QWidget(parent, name), Ui::RelatedFeedbackWidget()
+ : QWidget(parent), Ui::RelatedFeedbackWidget()
 {
 	if (name)
 		setObjectName(name);
@@ -26,14 +26,7 @@ RelatedFeedbackWidget::~RelatedFeedbackWidget()
 
 void RelatedFeedbackWidget::setClearButton( QPushButton * pButton, int index )
 {
-#warning make this more intelligent as soon as the designer offers naming of layouts again
-//	_pFeedbackLayout->insertWidget(index, pButton);
 	delete(_pClearButton);
 	_pClearButton = pButton;
-	QLayout* pLayout = new QHBoxLayout;
-	layout()->addItem(pLayout);
-	pLayout->setMargin(0);
-	pLayout->setSpacing(2);
-	pLayout->addWidget(_pClearButton);
-	pLayout->addWidget(_pRelatedSearchTextView);
+	_pFeedbackLayout->insertWidget(index, _pClearButton);
 }
